changeset 441:41489edbdf76

* src/vectors.S: Added GRUB startup option to tests for IDT initialization. Added call to breakpoint() before cyg_start(), controlled by CYGDBG_HAL_DEBUG_GDB_INITIAL_BREAK.
author nickg
date Sun, 01 Dec 2002 15:50:14 +0000
parents d2722bc50510
children cb9bc921600a
files packages/hal/i386/arch/current/ChangeLog packages/hal/i386/arch/current/src/vectors.S
diffstat 2 files changed, 16 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/packages/hal/i386/arch/current/ChangeLog
+++ b/packages/hal/i386/arch/current/ChangeLog
@@ -1,3 +1,9 @@
+2002-11-28  Nick Garnett  <nickg@ecoscentric.com>
+
+	* src/vectors.S: Added GRUB startup option to tests for IDT
+	initialization. Added call to breakpoint() before cyg_start(),
+	controlled by CYGDBG_HAL_DEBUG_GDB_INITIAL_BREAK.
+
 2002-05-17  Nick Garnett  <nickg@redhat.com>
 
 	* src/vectors.S: Rearranged interrupt stack definitions to make it
--- a/packages/hal/i386/arch/current/src/vectors.S
+++ b/packages/hal/i386/arch/current/src/vectors.S
@@ -91,7 +91,9 @@
 	
 	movl	$__interrupt_stack, %esp
 
-#if defined(CYG_HAL_STARTUP_FLOPPY) || defined(CYG_HAL_STARTUP_ROM)
+#if defined(CYG_HAL_STARTUP_FLOPPY) \
+    || defined(CYG_HAL_STARTUP_ROM) \
+    || defined(CYG_HAL_STARTUP_GRUB)
 	# If we are here first, initialize the IDT. RAM startup
 	# configurations can assume that Redboot has already set
 	# the IDT up.
@@ -153,15 +155,19 @@
 
 #ifndef CYG_HAL_STARTUP_RAM
 	# Only start other CPUs when we are the original boot executable.
 	# RAM executables are loaded via RedBoot, so only FLOPPY and ROM 
 	# startups count here.
 	
 	.extern cyg_hal_smp_cpu_start_all
 	call cyg_hal_smp_cpu_start_all
 #endif
 		
 #endif
-		
+
+#ifdef CYGDBG_HAL_DEBUG_GDB_INITIAL_BREAK
+        .extern breakpoint
+        call breakpoint
+#endif        
 	.extern cyg_start
 	call	cyg_start
@@ -153,15 +155,19 @@
 #ifndef CYG_HAL_STARTUP_RAM
 	# Only start other CPUs when we are the original boot executable.
-	# RAM executables are loaded via RedBoot, so only FLOPPY and ROM 
-	# startups count here.
+	# RAM executables are loaded via RedBoot, so only FLOPPY, GRUB 
+        # and ROM startups count here.
 	
 	.extern cyg_hal_smp_cpu_start_all